==> qmmp-plugin-pack-0.9.5.tar.bz2: qmmp-plugin-pack-0.9.5/src/Input/ffap/translations/ffap_plugin_fr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="fr">
<context>
    <name>DecoderFFapFactory</name>
    <message>
        <location filename="../decoderffapfactory.cpp" line="59"/>
        <source>FFap Plugin</source>
        <translation>Plugin FFap</translation>
    </message>
    <message>
        <location filename="../decoderffapfactory.cpp" line="61"/>
        <source>Monkey&apos;s Audio Files</source>
        <translation>Fichiers audio Monkey</translation>
    </message>
    <message>
        <location filename="../decoderffapfactory.cpp" line="169"/>
        <source>About FFap Audio Plugin</source>
        <translation>A propos du plugin audio FFap</translation>
    </message>
    <message>
        <location filename="../decoderffapfactory.cpp" line="170"/>
        <source>Qmmp FFap Audio Plugin</source>
        <translation>Plugin audio FFap Qmmp</translation>
    </message>
    <message>
        <location filename="../decoderffapfactory.cpp" line="171"/>
        <source>This plugin provides Monkey&apos;s Audio (APE) support</source>
        <translation>Ce plugin fournit le support des fichiers audio Monkey (APE)</translation>
    </message>
    <message>
        <location filename="../decoderffapfactory.cpp" line="172"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>Ecrit par: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
    <message>
        <location filename="../decoderffapfactory.cpp" line="173"/>
        <source>Based on code from deadbeef, FFmpeg and rockbox</source>
        <translation>Basé sur le code de deadbeef, FFmpeg et rockbox</translation>
    </message>
</context>
<context>
    <name>FFapMetaDataModel</name>
    <message>
        <location filename="../ffapmetadatamodel.cpp" line="68"/>
        <source>Length</source>
        <translation>Longueur</translation>
    </message>
    <message>
        <location filename="../ffapmetadatamodel.cpp" line="69"/>
        <source>Sample rate</source>
        <translation>Taux du sample</translation>
    </message>
    <message>
        <location filename="../ffapmetadatamodel.cpp" line="69"/>
        <source>Hz</source>
        <translation>Hz</translation>
    </message>
    <message>
        <location filename="../ffapmetadatamodel.cpp" line="70"/>
        <source>Channels</source>
        <translation>Canaux</translation>
    </message>
    <message>
        <location filename="../ffapmetadatamodel.cpp" line="71"/>
        <source>Bitrate</source>
        <translation>Taux de bit</translation>
    </message>
    <message>
        <location filename="../ffapmetadatamodel.cpp" line="71"/>
        <source>kbps</source>
        <translation>kbps</translation>
    </message>
    <message>
        <location filename="../ffapmetadatamodel.cpp" line="72"/>
        <source>File size</source>
        <translation>Taille du fichier</translation>
    </message>
    <message>
        <location filename="../ffapmetadatamodel.cpp" line="72"/>
        <source>KB</source>
        <translation>KB</translation>
    </message>
</context>
</TS>

==> qmmp-plugin-pack-0.10.3.tar.bz2: qmmp-plugin-pack-0.10.3/src/Input/ffap/translations/ffap_plugin_fr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="fr">
<context>
    <name>DecoderFFapFactory</name>
    <message>
        <location filename="../decoderffapfactory.cpp" line="53"/>
        <source>FFap Plugin</source>
        <translation>Plugin FFap</translation>
    </message>
    <message>
        <location filename="../decoderffapfactory.cpp" line="55"/>
        <source>Monkey&apos;s Audio Files</source>
        <translation>Fichiers audio Monkey</translation>
    </message>
    <message>
        <location filename="../decoderffapfactory.cpp" line="163"/>
        <source>About FFap Audio Plugin</source>
        <translation>A propos du plugin audio FFap</translation>
    </message>
    <message>
        <location filename="../decoderffapfactory.cpp" line="164"/>
        <source>Qmmp FFap Audio Plugin</source>
        <translation>Plugin audio FFap Qmmp</translation>
    </message>
    <message>
        <location filename="../decoderffapfactory.cpp" line="165"/>
        <source>This plugin provides Monkey&apos;s Audio (APE) support</source>
        <translation>Ce plugin fournit le support des fichiers audio Monkey (APE)</translation>
    </message>
    <message>
        <location filename="../decoderffapfactory.cpp" line="166"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>Ecrit par: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
    <message>
        <location filename="../decoderffapfactory.cpp" line="167"/>
        <source>Based on code from deadbeef, FFmpeg and rockbox</source>
        <translation>Basé sur le code de deadbeef, FFmpeg et rockbox</translation>
    </message>
</context>
<context>
    <name>FFapMetaDataModel</name>
    <message>
        <location filename="../ffapmetadatamodel.cpp" line="60"/>
        <source>Length</source>
        <translation>Longueur</translation>
    </message>
    <message>
        <location filename="../ffapmetadatamodel.cpp" line="61"/>
        <source>Sample rate</source>
        <translation>Taux de sample</translation>
    </message>
    <message>
        <location filename="../ffapmetadatamodel.cpp" line="61"/>
        <source>Hz</source>
        <translation>Hz</translation>
    </message>
    <message>
        <location filename="../ffapmetadatamodel.cpp" line="62"/>
        <source>Channels</source>
        <translation>Canaux</translation>
    </message>
    <message>
        <location filename="../ffapmetadatamodel.cpp" line="63"/>
        <source>Bitrate</source>
        <translation>Taux de bit</translation>
    </message>
    <message>
        <location filename="../ffapmetadatamodel.cpp" line="63"/>
        <source>kbps</source>
        <translation>kbps</translation>
    </message>
    <message>
        <location filename="../ffapmetadatamodel.cpp" line="64"/>
        <source>File size</source>
        <translation>Taille du fichier</translation>
    </message>
    <message>
        <location filename="../ffapmetadatamodel.cpp" line="64"/>
        <source>KB</source>
        <translation>KB</translation>
    </message>
</context>
</TS>
